@@ -54,8 +54,8 @@ def parse_content_range(content_range, resumed_from):
         raise ContentRangeError('Missing Content-Range')
 
     pattern = (
-        '^bytes (?P<first_byte_pos>\d+)-(?P<last_byte_pos>\d+)'
-        '/(\*|(?P<instance_length>\d+))$'
+        r'^bytes (?P<first_byte_pos>\d+)-(?P<last_byte_pos>\d+)'
+        r'/(\*|(?P<instance_length>\d+))$'
     )
     match = re.match(pattern, content_range)
 
@@ -78,15 +78,15 @@ def parse_content_range(content_range, resumed_from):
     # last-byte-pos value, is invalid. The recipient of an invalid
     # byte-content-range- spec MUST ignore it and any content
     # transferred along with it."
-    if (first_byte_pos >= last_byte_pos or
-            (instance_length is not None and
-             instance_length <= last_byte_pos)):
+    if (first_byte_pos >= last_byte_pos
+            or (instance_length is not None
+                and instance_length <= last_byte_pos)):
         raise ContentRangeError(
             'Invalid Content-Range returned: %r' % content_range)
 
-    if (first_byte_pos != resumed_from or
-            (instance_length is not None and
-             last_byte_pos + 1 != instance_length)):
+    if (first_byte_pos != resumed_from
+            or (instance_length is not None
+                and last_byte_pos + 1 != instance_length)):
         # Not what we asked for.
         raise ContentRangeError(
             'Unexpected Content-Range returned (%r)'
@@ -105,7 +105,7 @@ def filename_from_content_disposition(content_disposition):
     :return: the filename if present and valid, otherwise `None`
 
     """
-    # attachment; filename=jkbrzt-httpie-0.4.1-20-g40bd8f6.tar.gz
+    # attachment; filename=jakubroztocil-httpie-0.4.1-20-g40bd8f6.tar.gz
 
     msg = Message('Content-Disposition: %s' % content_disposition)
     filename = msg.get_filename()
@@ -224,13 +224,13 @@ class Downloader(object):
                 request_headers['Range'] = 'bytes=%d-' % bytes_have
                 self._resumed_from = bytes_have
 
-    def start(self, response):
+    def start(self, final_response):
         """
         Initiate and return a stream for `response` body  with progress
         callback attached. Can be called only once.
 
-        :param response: Initiated response object with headers already fetched
-        :type response: requests.models.Response
+        :param final_response: Initiated response object with headers already fetched
+        :type final_response: requests.models.Response
 
         :return: RawStream, output_file
 
@@ -238,16 +238,20 @@ class Downloader(object):
         assert not self.status.time_started
 
         # FIXME: some servers still might sent Content-Encoding: gzip
-        # <https://github.com/jkbrzt/httpie/issues/423>
+        # <https://github.com/jakubroztocil/httpie/issues/423>
         try:
-            total_size = int(response.headers['Content-Length'])
+            total_size = int(final_response.headers['Content-Length'])
         except (KeyError, ValueError, TypeError):
             total_size = None
 
-        if self._output_file:
-            if self._resume and response.status_code == PARTIAL_CONTENT:
+        if not self._output_file:
+            self._output_file = self._get_output_file_from_response(
+                final_response)
+        else:
+            # `--output, -o` provided
+            if self._resume and final_response.status_code == PARTIAL_CONTENT:
                 total_size = parse_content_range(
-                    response.headers.get('Content-Range'),
+                    final_response.headers.get('Content-Range'),
                     self._resumed_from
                 )
 
@@ -258,19 +262,6 @@ class Downloader(object):
                     self._output_file.truncate()
                 except IOError:
                     pass  # stdout
-        else:
-            # TODO: Should the filename be taken from response.history[0].url?
-            # Output file not specified. Pick a name that doesn't exist yet.
-            filename = None
-            if 'Content-Disposition' in response.headers:
-                filename = filename_from_content_disposition(
-                    response.headers['Content-Disposition'])
-            if not filename:
-                filename = filename_from_url(
-                    url=response.url,
-                    content_type=response.headers.get('Content-Type'),
-                )
-            self._output_file = open(get_unique_filename(filename), mode='a+b')
 
         self.status.started(
             resumed_from=self._resumed_from,
@@ -278,7 +269,7 @@ class Downloader(object):
         )
 
         stream = RawStream(
-            msg=HTTPResponse(response),
+            msg=HTTPResponse(final_response),
             with_headers=False,
             with_body=True,
             on_body_chunk_downloaded=self.chunk_downloaded,
@@ -308,9 +299,9 @@ class Downloader(object):
     @property
     def interrupted(self):
         return (
-            self.finished and
-            self.status.total_size and
-            self.status.total_size != self.status.downloaded
+            self.finished
+            and self.status.total_size
+            and self.status.total_size != self.status.downloaded
         )
 
     def chunk_downloaded(self, chunk):
@@ -324,6 +315,25 @@ class Downloader(object):
         """
         self.status.chunk_downloaded(len(chunk))
 
+    @staticmethod
+    def _get_output_file_from_response(final_response):
+        # Output file not specified. Pick a name that doesn't exist yet.
+        filename = None
+        if 'Content-Disposition' in final_response.headers:
+            filename = filename_from_content_disposition(
+                final_response.headers['Content-Disposition'])
+        if not filename:
+            initial_response = (
+                final_response.history[0] if final_response.history
+                else final_response
+            )
+            filename = filename_from_url(
+                url=initial_response.url,
+                content_type=final_response.headers.get('Content-Type'),
+            )
+        unique_filename = get_unique_filename(filename)
+        return open(unique_filename, mode='a+b')
+
 
 class Status(object):
     """Holds details about the downland status."""
@@ -399,8 +409,8 @@ class ProgressReporterThread(threading.Thread):
         if now - self._prev_time >= self._update_interval:
             downloaded = self.status.downloaded
             try:
-                speed = ((downloaded - self._prev_bytes) /
-                         (now - self._prev_time))
+                speed = ((downloaded - self._prev_bytes)
+                         / (now - self._prev_time))
             except ZeroDivisionError:
                 speed = 0
 
@@ -434,11 +444,11 @@ class ProgressReporterThread(threading.Thread):
             self._prev_bytes = downloaded
 
         self.output.write(
-            CLEAR_LINE +
-            ' ' +
-            SPINNER[self._spinner_pos] +
-            ' ' +
-            self._status_line
+            CLEAR_LINE
+            + ' '
+            + SPINNER[self._spinner_pos]
+            + ' '
+            + self._status_line
         )
         self.output.flush()
 
@@ -463,8 +473,8 @@ class ProgressReporterThread(threading.Thread):
 
         self.output.write(SUMMARY.format(
             downloaded=humanize_bytes(actually_downloaded),
-            total=(self.status.total_size and
-                   humanize_bytes(self.status.total_size)),
+            total=(self.status.total_size
+                   and humanize_bytes(self.status.total_size)),
             speed=humanize_bytes(speed),
             time=time_taken,
         ))
