@@ -39,8 +39,7 @@ class PluginManager(object):
         return [plugin for plugin in self if issubclass(plugin, AuthPlugin)]
 
     def get_auth_plugin_mapping(self):
-        return dict((plugin.auth_type, plugin)
-                    for plugin in self.get_auth_plugins())
+        return {plugin.auth_type: plugin for plugin in self.get_auth_plugins()}
 
     def get_auth_plugin(self, auth_type):
         return self.get_auth_plugin_mapping()[auth_type]
