@@ -1,7 +1,7 @@
 import mock
 
 from httpie import ExitStatus
-from utils import TestEnvironment, http, HTTP_OK
+from utils import MockEnvironment, http, HTTP_OK
 
 
 def test_keyboard_interrupt_during_arg_parsing_exit_status(httpbin):
@@ -21,26 +21,26 @@ def test_keyboard_interrupt_in_program_exit_status(httpbin):
 def test_ok_response_exits_0(httpbin):
     r = http('GET', httpbin.url + '/get')
     assert HTTP_OK in r
-    assert r.exit_status == ExitStatus.OK
+    assert r.exit_status == ExitStatus.SUCCESS
 
 
 def test_error_response_exits_0_without_check_status(httpbin):
     r = http('GET', httpbin.url + '/status/500')
-    assert '500 INTERNAL SERVER ERRO' in r
-    assert r.exit_status == ExitStatus.OK
+    assert '500 INTERNAL SERVER ERROR' in r
+    assert r.exit_status == ExitStatus.SUCCESS
     assert not r.stderr
 
 
 def test_timeout_exit_status(httpbin):
 
-    r = http('--timeout=0.01', 'GET', httpbin.url + '/delay/0.02',
+    r = http('--timeout=0.01', 'GET', httpbin.url + '/delay/0.5',
              error_exit_ok=True)
     assert r.exit_status == ExitStatus.ERROR_TIMEOUT
 
 
 def test_3xx_check_status_exits_3_and_stderr_when_stdout_redirected(
         httpbin):
-    env = TestEnvironment(stdout_isatty=False)
+    env = MockEnvironment(stdout_isatty=False)
     r = http('--check-status', '--headers',
              'GET', httpbin.url + '/status/301',
              env=env, error_exit_ok=True)
@@ -55,7 +55,7 @@ def test_3xx_check_status_redirects_allowed_exits_0(httpbin):
              error_exit_ok=True)
     # The redirect will be followed so 200 is expected.
     assert HTTP_OK in r
-    assert r.exit_status == ExitStatus.OK
+    assert r.exit_status == ExitStatus.SUCCESS
 
 
 def test_4xx_check_status_exits_4(httpbin):
