@@ -2,28 +2,27 @@
 import pytest
 
 from httpie.input import ParseError
-from utils import TestEnvironment, http, HTTP_OK
+from utils import MockEnvironment, http, HTTP_OK
 from fixtures import FILE_PATH, FILE_CONTENT
 
 import httpie
-from httpie.compat import is_py26
 
 
 def test_debug():
     r = http('--debug')
-    assert r.exit_status == httpie.ExitStatus.OK
+    assert r.exit_status == httpie.ExitStatus.SUCCESS
     assert 'HTTPie %s' % httpie.__version__ in r.stderr
 
 
 def test_help():
     r = http('--help', error_exit_ok=True)
-    assert r.exit_status == httpie.ExitStatus.OK
-    assert 'https://github.com/jkbrzt/httpie/issues' in r
+    assert r.exit_status == httpie.ExitStatus.SUCCESS
+    assert 'https://github.com/jakubroztocil/httpie/issues' in r
 
 
 def test_version():
     r = http('--version', error_exit_ok=True)
-    assert r.exit_status == httpie.ExitStatus.OK
+    assert r.exit_status == httpie.ExitStatus.SUCCESS
     # FIXME: py3 has version in stdout, py2 in stderr
     assert httpie.__version__ == r.stderr.strip() + r.strip()
 
@@ -64,7 +63,7 @@ def test_POST_form_multiple_values(httpbin_both):
 
 def test_POST_stdin(httpbin_both):
     with open(FILE_PATH) as f:
-        env = TestEnvironment(stdin=f, stdin_isatty=False)
+        env = MockEnvironment(stdin=f, stdin_isatty=False)
         r = http('--form', 'POST', httpbin_both + '/post', env=env)
     assert HTTP_OK in r
     assert FILE_CONTENT in r
@@ -107,10 +106,6 @@ def test_headers_empty_value_with_value_gives_error(httpbin):
         http('GET', httpbin + '/headers', 'Accept;SYNTAX_ERROR')
 
 
-@pytest.mark.skipif(
-    is_py26,
-    reason='the `object_pairs_hook` arg for `json.loads()` is Py>2.6 only'
-)
 def test_json_input_preserve_order(httpbin_both):
     r = http('PATCH', httpbin_both + '/patch',
              'order:={"map":{"1":"first","2":"second"}}')
