@@ -7,7 +7,7 @@ from tempfile import gettempdir
 import pytest
 
 from httpie.plugins.builtin import HTTPBasicAuth
-from utils import TestEnvironment, mk_config_dir, http, HTTP_OK
+from utils import MockEnvironment, mk_config_dir, http, HTTP_OK
 from fixtures import UNICODE
 
 
@@ -29,7 +29,7 @@ class SessionTestBase(object):
         for session files being reused.
 
         """
-        return TestEnvironment(config_dir=self.config_dir)
+        return MockEnvironment(config_dir=self.config_dir)
 
 
 class TestSessionFlow(SessionTestBase):
@@ -81,8 +81,8 @@ class TestSessionFlow(SessionTestBase):
         assert HTTP_OK in r4
         assert r4.json['headers']['Hello'] == 'World2'
         assert r4.json['headers']['Cookie'] == 'hello=world2'
-        assert (r2.json['headers']['Authorization'] !=
-                r4.json['headers']['Authorization'])
+        assert (r2.json['headers']['Authorization']
+                != r4.json['headers']['Authorization'])
 
     def test_session_read_only(self, httpbin):
         self.start_session(httpbin)
@@ -143,7 +143,7 @@ class TestSession(SessionTestBase):
     @pytest.mark.skipif(
         sys.version_info >= (3,),
         reason="This test fails intermittently on Python 3 - "
-               "see https://github.com/jkbrzt/httpie/issues/282")
+               "see https://github.com/jakubroztocil/httpie/issues/282")
     def test_session_unicode(self, httpbin):
         self.start_session(httpbin)
 
@@ -157,14 +157,14 @@ class TestSession(SessionTestBase):
         assert HTTP_OK in r2
 
         # FIXME: Authorization *sometimes* is not present on Python3
-        assert (r2.json['headers']['Authorization'] ==
-                HTTPBasicAuth.make_header(u'test', UNICODE))
+        assert (r2.json['headers']['Authorization']
+                == HTTPBasicAuth.make_header(u'test', UNICODE))
         # httpbin doesn't interpret utf8 headers
         assert UNICODE in r2
 
     def test_session_default_header_value_overwritten(self, httpbin):
         self.start_session(httpbin)
-        # https://github.com/jkbrzt/httpie/issues/180
+        # https://github.com/jakubroztocil/httpie/issues/180
         r1 = http('--session=test',
                   httpbin.url + '/headers', 'User-Agent:custom',
                   env=self.env())
@@ -176,7 +176,7 @@ class TestSession(SessionTestBase):
         assert r2.json['headers']['User-Agent'] == 'custom'
 
     def test_download_in_session(self, httpbin):
-        # https://github.com/jkbrzt/httpie/issues/412
+        # https://github.com/jakubroztocil/httpie/issues/412
         self.start_session(httpbin)
         cwd = os.getcwd()
         os.chdir(gettempdir())
